# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qm/pb/inc_qua_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='qm/pb/inc_qua_config.proto',
  package='qm.grpc.qua_config',
  syntax='proto3',
  serialized_options=b'P\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1aqm/pb/inc_qua_config.proto\x12\x12qm.grpc.qua_config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xf3=\n\tQuaConfig\x12;\n\x06v1beta\x18\x01 \x01(\x0b\x32).qm.grpc.qua_config.QuaConfig.QuaConfigV1H\x00\x12\x10\n\x08revision\x18\x0b \x01(\x05\x1a\x8e\x0b\n\x0bQuaConfigV1\x12O\n\x0b\x63ontrollers\x18\x02 \x03(\x0b\x32:.qm.grpc.qua_config.QuaConfig.QuaConfigV1.ControllersEntry\x12O\n\x0boscillators\x18\t \x03(\x0b\x32:.qm.grpc.qua_config.QuaConfig.QuaConfigV1.OscillatorsEntry\x12I\n\x08\x65lements\x18\x03 \x03(\x0b\x32\x37.qm.grpc.qua_config.QuaConfig.QuaConfigV1.ElementsEntry\x12\x45\n\x06pulses\x18\x04 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.QuaConfigV1.PulsesEntry\x12\x45\n\x06mixers\x18\x05 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.QuaConfigV1.MixersEntry\x12K\n\twaveforms\x18\x06 \x03(\x0b\x32\x38.qm.grpc.qua_config.QuaConfig.QuaConfigV1.WaveformsEntry\x12Y\n\x10\x64igitalWaveforms\x18\x07 \x03(\x0b\x32?.qm.grpc.qua_config.QuaConfig.QuaConfigV1.DigitalWaveformsEntry\x12]\n\x12integrationWeights\x18\x08 \x03(\x0b\x32\x41.qm.grpc.qua_config.QuaConfig.QuaConfigV1.IntegrationWeightsEntry\x1a_\n\x10\x43ontrollersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.ControllerDec:\x02\x38\x01\x1a\\\n\x10OscillatorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.qm.grpc.qua_config.QuaConfig.Oscillator:\x02\x38\x01\x1aY\n\rElementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.qm.grpc.qua_config.QuaConfig.ElementDec:\x02\x38\x01\x1aU\n\x0bPulsesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.qm.grpc.qua_config.QuaConfig.PulseDec:\x02\x38\x01\x1aU\n\x0bMixersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.qm.grpc.qua_config.QuaConfig.MixerDec:\x02\x38\x01\x1a[\n\x0eWaveformsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).qm.grpc.qua_config.QuaConfig.WaveformDec:\x02\x38\x01\x1ai\n\x15\x44igitalWaveformsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.qm.grpc.qua_config.QuaConfig.DigitalWaveformDec:\x02\x38\x01\x1am\n\x17IntegrationWeightsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.IntegrationWeightDec:\x02\x38\x01\x1a\x9d\x06\n\rControllerDec\x12\x0c\n\x04type\x18\x01 \x01(\t\x12U\n\ranalogOutputs\x18\x02 \x03(\x0b\x32>.qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogOutputsEntry\x12S\n\x0c\x61nalogInputs\x18\x03 \x03(\x0b\x32=.qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogInputsEntry\x12W\n\x0e\x64igitalOutputs\x18\x04 \x03(\x0b\x32?.qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalOutputsEntry\x12U\n\rdigitalInputs\x18\x05 \x03(\x0b\x32>.qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalInputsEntry\x1ag\n\x12\x41nalogOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec:\x02\x38\x01\x1a\x65\n\x11\x41nalogInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.qm.grpc.qua_config.QuaConfig.AnalogInputPortDec:\x02\x38\x01\x1ai\n\x13\x44igitalOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.DigitalOutputPortDec:\x02\x38\x01\x1ag\n\x12\x44igitalInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.qm.grpc.qua_config.QuaConfig.DigitalInputPortDec:\x02\x38\x01\x1a\x90\x02\n\x13\x41nalogOutputPortDec\x12\x0e\n\x06offset\x18\x01 \x01(\x01\x12\x44\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x34.qm.grpc.qua_config.QuaConfig.AnalogOutputPortFilter\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\r\x12]\n\x0e\x63hannelWeights\x18\x04 \x03(\x0b\x32\x45.qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec.ChannelWeightsEntry\x1a\x35\n\x13\x43hannelWeightsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a?\n\x16\x41nalogOutputPortFilter\x12\x13\n\x0b\x66\x65\x65\x64\x66orward\x18\x01 \x03(\x01\x12\x10\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x03(\x01\x1aQ\n\x12\x41nalogInputPortDec\x12\x0e\n\x06offset\x18\x01 \x01(\x01\x12+\n\x06gainDb\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x1a\x16\n\x14\x44igitalOutputPortDec\x1a\xb3\x01\n\x13\x44igitalInputPortDec\x12\x0e\n\x06window\x18\x01 \x01(\r\x12L\n\x08polarity\x18\x02 \x01(\x0e\x32:.qm.grpc.qua_config.QuaConfig.DigitalInputPortDec.Polarity\x12\x11\n\tthreshold\x18\x03 \x01(\x01\"+\n\x08Polarity\x12\x0f\n\x0b\x41\x43TIVE_HIGH\x10\x00\x12\x0e\n\nACTIVE_LOW\x10\x01\x1a.\n\x08MixerRef\x12\r\n\x05mixer\x18\x01 \x01(\t\x12\x13\n\x0bloFrequency\x18\x02 \x01(\x04\x1a\x7f\n\nOscillator\x12:\n\x15intermediateFrequency\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x05mixer\x18\x02 \x01(\x0b\x32&.qm.grpc.qua_config.QuaConfig.MixerRef\x1aK\n\x0bSingleInput\x12<\n\x04port\x18\x01 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference\x1a\xa5\x01\n\tMixInputs\x12\x39\n\x01I\x18\x01 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference\x12\x39\n\x01Q\x18\x02 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference\x12\r\n\x05mixer\x18\x03 \x01(\t\x12\x13\n\x0bloFrequency\x18\x04 \x01(\x04\x1a\xc7\x01\n\x15SingleInputCollection\x12O\n\x06inputs\x18\x01 \x03(\x0b\x32?.qm.grpc.qua_config.QuaConfig.SingleInputCollection.InputsEntry\x1a]\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference:\x02\x38\x01\x1a\xb9\x01\n\x0eMultipleInputs\x12H\n\x06inputs\x18\x01 \x03(\x0b\x32\x38.qm.grpc.qua_config.QuaConfig.MultipleInputs.InputsEntry\x1a]\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference:\x02\x38\x01\x1a\x88\r\n\nElementDec\x12\x46\n\x07outputs\x18\x03 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.ElementDec.OutputsEntry\x12R\n\rdigitalInputs\x18\x04 \x03(\x0b\x32;.qm.grpc.qua_config.QuaConfig.ElementDec.DigitalInputsEntry\x12T\n\x0e\x64igitalOutputs\x18\t \x03(\x0b\x32<.qm.grpc.qua_config.QuaConfig.ElementDec.DigitalOutputsEntry\x12@\n\x0bsingleInput\x18\x05 \x01(\x0b\x32).qm.grpc.qua_config.QuaConfig.SingleInputH\x00\x12<\n\tmixInputs\x18\x06 \x01(\x0b\x32\'.qm.grpc.qua_config.QuaConfig.MixInputsH\x00\x12T\n\x15singleInputCollection\x18\x32 \x01(\x0b\x32\x33.qm.grpc.qua_config.QuaConfig.SingleInputCollectionH\x00\x12\x46\n\x0emultipleInputs\x18\x33 \x01(\x0b\x32,.qm.grpc.qua_config.QuaConfig.MultipleInputsH\x00\x12\x32\n\x0ctimeOfFlight\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12.\n\x08smearing\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12;\n\x15intermediateFrequency\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12%\n\x1dintermediateFrequencyNegative\x18\x17 \x01(\x08\x12L\n\noperations\x18\x15 \x03(\x0b\x32\x38.qm.grpc.qua_config.QuaConfig.ElementDec.OperationsEntry\x12\x33\n\rmeasurementQe\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12R\n\x15outputPulseParameters\x18\x1e \x01(\x0b\x32\x33.qm.grpc.qua_config.QuaConfig.OutputPulseParameters\x12<\n\nholdOffset\x18\x1f \x01(\x0b\x32(.qm.grpc.qua_config.QuaConfig.HoldOffset\x12;\n\x06thread\x18( \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.ElementThread\x12\x46\n\x1fintermediateFrequencyOscillator\x18= \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x01\x12\x37\n\x0fnamedOscillator\x18> \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x01\x12.\n\x0cnoOscillator\x18? \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x1a^\n\x0cOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.AdcPortReference:\x02\x38\x01\x1am\n\x12\x44igitalInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.qm.grpc.qua_config.QuaConfig.DigitalInputPortReference:\x02\x38\x01\x1ao\n\x13\x44igitalOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12G\n\x05value\x18\x02 \x01(\x0b\x32\x38.qm.grpc.qua_config.QuaConfig.DigitalOutputPortReference:\x02\x38\x01\x1a\x31\n\x0fOperationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x17\n\x15\x65lement_inputs_one_ofB\x13\n\x11oscillator_one_of\x1a#\n\rElementThread\x12\x12\n\nthreadName\x18\x01 \x01(\t\x1a\xd2\x02\n\x15OutputPulseParameters\x12\x15\n\tthreshold\x18\x01 \x01(\rB\x02\x18\x01\x12\x11\n\x05table\x18\x02 \x03(\rB\x02\x18\x01\x12\x17\n\x0fsignalThreshold\x18\x03 \x01(\x05\x12T\n\x0esignalPolarity\x18\x04 \x01(\x0e\x32<.qm.grpc.qua_config.QuaConfig.OutputPulseParameters.Polarity\x12\x1b\n\x13\x64\x65rivativeThreshold\x18\x05 \x01(\x05\x12X\n\x12\x64\x65rivativePolarity\x18\x06 \x01(\x0e\x32<.qm.grpc.qua_config.QuaConfig.OutputPulseParameters.Polarity\")\n\x08Polarity\x12\r\n\tASCENDING\x10\x00\x12\x0e\n\nDESCENDING\x10\x01\x1a\x1e\n\nHoldOffset\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\x1a\x36\n\x10\x44\x61\x63PortReference\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\r\x1a\x36\n\x10\x41\x64\x63PortReference\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\r\x1au\n\x19\x44igitalInputPortReference\x12\x39\n\x04port\x18\x01 \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.PortReference\x12\r\n\x05\x64\x65lay\x18\x02 \x01(\r\x12\x0e\n\x06\x62uffer\x18\x03 \x01(\r\x1aW\n\x1a\x44igitalOutputPortReference\x12\x39\n\x04port\x18\x01 \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.PortReference\x1a\x33\n\rPortReference\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\r\x1a\xa0\x03\n\x08PulseDec\x12\x0e\n\x06length\x18\x02 \x01(\r\x12\x11\n\toperation\x18\x03 \x01(\r\x12H\n\twaveforms\x18\x04 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.PulseDec.WaveformsEntry\x12\x33\n\rdigitalMarker\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x12integrationWeights\x18\x08 \x03(\x0b\x32>.qm.grpc.qua_config.QuaConfig.PulseDec.IntegrationWeightsEntry\x1a\x30\n\x0eWaveformsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17IntegrationWeightsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\tOperation\x12\x0f\n\x0bMEASUREMENT\x10\x00\x12\x0b\n\x07\x43ONTROL\x10\x01\x1a\xfe\x01\n\x0bWaveformDec\x12G\n\tarbitrary\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.ArbitraryWaveformDecH\x00\x12\x45\n\x08\x63onstant\x18\x02 \x01(\x0b\x32\x31.qm.grpc.qua_config.QuaConfig.ConstantWaveformDecH\x00\x12M\n\ncompressed\x18\x03 \x01(\x0b\x32\x33.qm.grpc.qua_config.QuaConfig.CompressedWaveformDecB\x02\x18\x01H\x00\x42\x10\n\x0ewaveform_oneof\x1a\xe4\x01\n\x14\x41rbitraryWaveformDec\x12\x0f\n\x07samples\x18\x01 \x03(\x01\x12\x12\n\nmultiplier\x18\x02 \x01(\x01\x12%\n\x19\x64\x65precatedMaxAllowedError\x18\x03 \x01(\x01\x42\x02\x18\x01\x12\x35\n\x0fmaxAllowedError\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x32\n\x0csamplingRate\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x15\n\risOverridable\x18\x06 \x01(\x08\x1a<\n\x15\x43ompressedWaveformDec\x12\x0f\n\x07samples\x18\x01 \x03(\x01\x12\x12\n\nsampleRate\x18\x02 \x01(\x01\x1a\x39\n\x13\x43onstantWaveformDec\x12\x0e\n\x06sample\x18\x01 \x01(\x01\x12\x12\n\nmultiplier\x18\x02 \x01(\x01\x1aZ\n\x12\x44igitalWaveformDec\x12\x44\n\x07samples\x18\x01 \x03(\x0b\x32\x33.qm.grpc.qua_config.QuaConfig.DigitalWaveformSample\x1a\x36\n\x15\x44igitalWaveformSample\x12\r\n\x05value\x18\x01 \x01(\x08\x12\x0e\n\x06length\x18\x02 \x01(\r\x1aM\n\x08MixerDec\x12\x41\n\ncorrection\x18\x01 \x03(\x0b\x32-.qm.grpc.qua_config.QuaConfig.CorrectionEntry\x1a\xa2\x01\n\x14IntegrationWeightDec\x12\x45\n\x06\x63osine\x18\x01 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.IntegrationWeightSample\x12\x43\n\x04sine\x18\x02 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.IntegrationWeightSample\x1a\x38\n\x17IntegrationWeightSample\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0e\n\x06length\x18\x02 \x01(\r\x1a\x8e\x01\n\x0f\x43orrectionEntry\x12\x11\n\tfrequency\x18\x01 \x01(\x04\x12\x13\n\x0bloFrequency\x18\x02 \x01(\x04\x12\x38\n\ncorrection\x18\x03 \x01(\x0b\x32$.qm.grpc.qua_config.QuaConfig.Matrix\x12\x19\n\x11\x66requencyNegative\x18\x04 \x01(\x08\x1a<\n\x06Matrix\x12\x0b\n\x03v00\x18\x01 \x01(\x01\x12\x0b\n\x03v01\x18\x02 \x01(\x01\x12\x0b\n\x03v10\x18\x03 \x01(\x01\x12\x0b\n\x03v11\x18\x04 \x01(\x01\x42\x10\n\x0e\x63onfig_versionJ\x04\x08\x02\x10\x0b\x42\x02P\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])



_QUACONFIG_DIGITALINPUTPORTDEC_POLARITY = _descriptor.EnumDescriptor(
  name='Polarity',
  full_name='qm.grpc.qua_config.QuaConfig.DigitalInputPortDec.Polarity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVE_HIGH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE_LOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3013,
  serialized_end=3056,
)
_sym_db.RegisterEnumDescriptor(_QUACONFIG_DIGITALINPUTPORTDEC_POLARITY)

_QUACONFIG_OUTPUTPULSEPARAMETERS_POLARITY = _descriptor.EnumDescriptor(
  name='Polarity',
  full_name='qm.grpc.qua_config.QuaConfig.OutputPulseParameters.Polarity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ASCENDING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DESCENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5880,
  serialized_end=5921,
)
_sym_db.RegisterEnumDescriptor(_QUACONFIG_OUTPUTPULSEPARAMETERS_POLARITY)

_QUACONFIG_PULSEDEC_OPERATION = _descriptor.EnumDescriptor(
  name='Operation',
  full_name='qm.grpc.qua_config.QuaConfig.PulseDec.Operation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MEASUREMENT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6704,
  serialized_end=6745,
)
_sym_db.RegisterEnumDescriptor(_QUACONFIG_PULSEDEC_OPERATION)


_QUACONFIG_QUACONFIGV1_CONTROLLERSENTRY = _descriptor.Descriptor(
  name='ControllersEntry',
  full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.ControllersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.ControllersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.ControllersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=957,
)

_QUACONFIG_QUACONFIGV1_OSCILLATORSENTRY = _descriptor.Descriptor(
  name='OscillatorsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.OscillatorsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.OscillatorsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.OscillatorsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=1051,
)

_QUACONFIG_QUACONFIGV1_ELEMENTSENTRY = _descriptor.Descriptor(
  name='ElementsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.ElementsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.ElementsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.ElementsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1053,
  serialized_end=1142,
)

_QUACONFIG_QUACONFIGV1_PULSESENTRY = _descriptor.Descriptor(
  name='PulsesEntry',
  full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.PulsesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.PulsesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.PulsesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1229,
)

_QUACONFIG_QUACONFIGV1_MIXERSENTRY = _descriptor.Descriptor(
  name='MixersEntry',
  full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.MixersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.MixersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.MixersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1231,
  serialized_end=1316,
)

_QUACONFIG_QUACONFIGV1_WAVEFORMSENTRY = _descriptor.Descriptor(
  name='WaveformsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.WaveformsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.WaveformsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.WaveformsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1318,
  serialized_end=1409,
)

_QUACONFIG_QUACONFIGV1_DIGITALWAVEFORMSENTRY = _descriptor.Descriptor(
  name='DigitalWaveformsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.DigitalWaveformsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.DigitalWaveformsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.DigitalWaveformsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1411,
  serialized_end=1516,
)

_QUACONFIG_QUACONFIGV1_INTEGRATIONWEIGHTSENTRY = _descriptor.Descriptor(
  name='IntegrationWeightsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.IntegrationWeightsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.IntegrationWeightsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.IntegrationWeightsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1518,
  serialized_end=1627,
)

_QUACONFIG_QUACONFIGV1 = _descriptor.Descriptor(
  name='QuaConfigV1',
  full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controllers', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.controllers', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oscillators', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.oscillators', index=1,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elements', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.elements', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pulses', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.pulses', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mixers', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.mixers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveforms', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.waveforms', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalWaveforms', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.digitalWaveforms', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integrationWeights', full_name='qm.grpc.qua_config.QuaConfig.QuaConfigV1.integrationWeights', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUACONFIG_QUACONFIGV1_CONTROLLERSENTRY, _QUACONFIG_QUACONFIGV1_OSCILLATORSENTRY, _QUACONFIG_QUACONFIGV1_ELEMENTSENTRY, _QUACONFIG_QUACONFIGV1_PULSESENTRY, _QUACONFIG_QUACONFIGV1_MIXERSENTRY, _QUACONFIG_QUACONFIGV1_WAVEFORMSENTRY, _QUACONFIG_QUACONFIGV1_DIGITALWAVEFORMSENTRY, _QUACONFIG_QUACONFIGV1_INTEGRATIONWEIGHTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=1627,
)

_QUACONFIG_CONTROLLERDEC_ANALOGOUTPUTSENTRY = _descriptor.Descriptor(
  name='AnalogOutputsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogOutputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogOutputsEntry.key', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogOutputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2009,
  serialized_end=2112,
)

_QUACONFIG_CONTROLLERDEC_ANALOGINPUTSENTRY = _descriptor.Descriptor(
  name='AnalogInputsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogInputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogInputsEntry.key', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogInputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2114,
  serialized_end=2215,
)

_QUACONFIG_CONTROLLERDEC_DIGITALOUTPUTSENTRY = _descriptor.Descriptor(
  name='DigitalOutputsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalOutputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalOutputsEntry.key', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalOutputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2217,
  serialized_end=2322,
)

_QUACONFIG_CONTROLLERDEC_DIGITALINPUTSENTRY = _descriptor.Descriptor(
  name='DigitalInputsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalInputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalInputsEntry.key', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalInputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2324,
  serialized_end=2427,
)

_QUACONFIG_CONTROLLERDEC = _descriptor.Descriptor(
  name='ControllerDec',
  full_name='qm.grpc.qua_config.QuaConfig.ControllerDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analogOutputs', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.analogOutputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analogInputs', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.analogInputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalOutputs', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.digitalOutputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalInputs', full_name='qm.grpc.qua_config.QuaConfig.ControllerDec.digitalInputs', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUACONFIG_CONTROLLERDEC_ANALOGOUTPUTSENTRY, _QUACONFIG_CONTROLLERDEC_ANALOGINPUTSENTRY, _QUACONFIG_CONTROLLERDEC_DIGITALOUTPUTSENTRY, _QUACONFIG_CONTROLLERDEC_DIGITALINPUTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1630,
  serialized_end=2427,
)

_QUACONFIG_ANALOGOUTPUTPORTDEC_CHANNELWEIGHTSENTRY = _descriptor.Descriptor(
  name='ChannelWeightsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec.ChannelWeightsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec.ChannelWeightsEntry.key', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec.ChannelWeightsEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2649,
  serialized_end=2702,
)

_QUACONFIG_ANALOGOUTPUTPORTDEC = _descriptor.Descriptor(
  name='AnalogOutputPortDec',
  full_name='qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec.offset', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec.filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec.delay', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channelWeights', full_name='qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec.channelWeights', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUACONFIG_ANALOGOUTPUTPORTDEC_CHANNELWEIGHTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2430,
  serialized_end=2702,
)

_QUACONFIG_ANALOGOUTPUTPORTFILTER = _descriptor.Descriptor(
  name='AnalogOutputPortFilter',
  full_name='qm.grpc.qua_config.QuaConfig.AnalogOutputPortFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feedforward', full_name='qm.grpc.qua_config.QuaConfig.AnalogOutputPortFilter.feedforward', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedback', full_name='qm.grpc.qua_config.QuaConfig.AnalogOutputPortFilter.feedback', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2704,
  serialized_end=2767,
)

_QUACONFIG_ANALOGINPUTPORTDEC = _descriptor.Descriptor(
  name='AnalogInputPortDec',
  full_name='qm.grpc.qua_config.QuaConfig.AnalogInputPortDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='qm.grpc.qua_config.QuaConfig.AnalogInputPortDec.offset', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gainDb', full_name='qm.grpc.qua_config.QuaConfig.AnalogInputPortDec.gainDb', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2769,
  serialized_end=2850,
)

_QUACONFIG_DIGITALOUTPUTPORTDEC = _descriptor.Descriptor(
  name='DigitalOutputPortDec',
  full_name='qm.grpc.qua_config.QuaConfig.DigitalOutputPortDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2852,
  serialized_end=2874,
)

_QUACONFIG_DIGITALINPUTPORTDEC = _descriptor.Descriptor(
  name='DigitalInputPortDec',
  full_name='qm.grpc.qua_config.QuaConfig.DigitalInputPortDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='window', full_name='qm.grpc.qua_config.QuaConfig.DigitalInputPortDec.window', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polarity', full_name='qm.grpc.qua_config.QuaConfig.DigitalInputPortDec.polarity', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='qm.grpc.qua_config.QuaConfig.DigitalInputPortDec.threshold', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _QUACONFIG_DIGITALINPUTPORTDEC_POLARITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2877,
  serialized_end=3056,
)

_QUACONFIG_MIXERREF = _descriptor.Descriptor(
  name='MixerRef',
  full_name='qm.grpc.qua_config.QuaConfig.MixerRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mixer', full_name='qm.grpc.qua_config.QuaConfig.MixerRef.mixer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loFrequency', full_name='qm.grpc.qua_config.QuaConfig.MixerRef.loFrequency', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3058,
  serialized_end=3104,
)

_QUACONFIG_OSCILLATOR = _descriptor.Descriptor(
  name='Oscillator',
  full_name='qm.grpc.qua_config.QuaConfig.Oscillator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intermediateFrequency', full_name='qm.grpc.qua_config.QuaConfig.Oscillator.intermediateFrequency', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mixer', full_name='qm.grpc.qua_config.QuaConfig.Oscillator.mixer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3106,
  serialized_end=3233,
)

_QUACONFIG_SINGLEINPUT = _descriptor.Descriptor(
  name='SingleInput',
  full_name='qm.grpc.qua_config.QuaConfig.SingleInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='qm.grpc.qua_config.QuaConfig.SingleInput.port', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3235,
  serialized_end=3310,
)

_QUACONFIG_MIXINPUTS = _descriptor.Descriptor(
  name='MixInputs',
  full_name='qm.grpc.qua_config.QuaConfig.MixInputs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='I', full_name='qm.grpc.qua_config.QuaConfig.MixInputs.I', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Q', full_name='qm.grpc.qua_config.QuaConfig.MixInputs.Q', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mixer', full_name='qm.grpc.qua_config.QuaConfig.MixInputs.mixer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loFrequency', full_name='qm.grpc.qua_config.QuaConfig.MixInputs.loFrequency', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3313,
  serialized_end=3478,
)

_QUACONFIG_SINGLEINPUTCOLLECTION_INPUTSENTRY = _descriptor.Descriptor(
  name='InputsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.SingleInputCollection.InputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.SingleInputCollection.InputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.SingleInputCollection.InputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3587,
  serialized_end=3680,
)

_QUACONFIG_SINGLEINPUTCOLLECTION = _descriptor.Descriptor(
  name='SingleInputCollection',
  full_name='qm.grpc.qua_config.QuaConfig.SingleInputCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='qm.grpc.qua_config.QuaConfig.SingleInputCollection.inputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUACONFIG_SINGLEINPUTCOLLECTION_INPUTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3481,
  serialized_end=3680,
)

_QUACONFIG_MULTIPLEINPUTS_INPUTSENTRY = _descriptor.Descriptor(
  name='InputsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.MultipleInputs.InputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.MultipleInputs.InputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.MultipleInputs.InputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3587,
  serialized_end=3680,
)

_QUACONFIG_MULTIPLEINPUTS = _descriptor.Descriptor(
  name='MultipleInputs',
  full_name='qm.grpc.qua_config.QuaConfig.MultipleInputs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='qm.grpc.qua_config.QuaConfig.MultipleInputs.inputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUACONFIG_MULTIPLEINPUTS_INPUTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3683,
  serialized_end=3868,
)

_QUACONFIG_ELEMENTDEC_OUTPUTSENTRY = _descriptor.Descriptor(
  name='OutputsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.ElementDec.OutputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.OutputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.OutputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5128,
  serialized_end=5222,
)

_QUACONFIG_ELEMENTDEC_DIGITALINPUTSENTRY = _descriptor.Descriptor(
  name='DigitalInputsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.ElementDec.DigitalInputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.DigitalInputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.DigitalInputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5224,
  serialized_end=5333,
)

_QUACONFIG_ELEMENTDEC_DIGITALOUTPUTSENTRY = _descriptor.Descriptor(
  name='DigitalOutputsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.ElementDec.DigitalOutputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.DigitalOutputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.DigitalOutputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5335,
  serialized_end=5446,
)

_QUACONFIG_ELEMENTDEC_OPERATIONSENTRY = _descriptor.Descriptor(
  name='OperationsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.ElementDec.OperationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.OperationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.OperationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5448,
  serialized_end=5497,
)

_QUACONFIG_ELEMENTDEC = _descriptor.Descriptor(
  name='ElementDec',
  full_name='qm.grpc.qua_config.QuaConfig.ElementDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputs', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.outputs', index=0,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalInputs', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.digitalInputs', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalOutputs', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.digitalOutputs', index=2,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='singleInput', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.singleInput', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mixInputs', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.mixInputs', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='singleInputCollection', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.singleInputCollection', index=5,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multipleInputs', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.multipleInputs', index=6,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeOfFlight', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.timeOfFlight', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smearing', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.smearing', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intermediateFrequency', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.intermediateFrequency', index=9,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intermediateFrequencyNegative', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.intermediateFrequencyNegative', index=10,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operations', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.operations', index=11,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurementQe', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.measurementQe', index=12,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputPulseParameters', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.outputPulseParameters', index=13,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='holdOffset', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.holdOffset', index=14,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thread', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.thread', index=15,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intermediateFrequencyOscillator', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.intermediateFrequencyOscillator', index=16,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namedOscillator', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.namedOscillator', index=17,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='noOscillator', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.noOscillator', index=18,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUACONFIG_ELEMENTDEC_OUTPUTSENTRY, _QUACONFIG_ELEMENTDEC_DIGITALINPUTSENTRY, _QUACONFIG_ELEMENTDEC_DIGITALOUTPUTSENTRY, _QUACONFIG_ELEMENTDEC_OPERATIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='element_inputs_one_of', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.element_inputs_one_of',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='oscillator_one_of', full_name='qm.grpc.qua_config.QuaConfig.ElementDec.oscillator_one_of',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3871,
  serialized_end=5543,
)

_QUACONFIG_ELEMENTTHREAD = _descriptor.Descriptor(
  name='ElementThread',
  full_name='qm.grpc.qua_config.QuaConfig.ElementThread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='threadName', full_name='qm.grpc.qua_config.QuaConfig.ElementThread.threadName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5545,
  serialized_end=5580,
)

_QUACONFIG_OUTPUTPULSEPARAMETERS = _descriptor.Descriptor(
  name='OutputPulseParameters',
  full_name='qm.grpc.qua_config.QuaConfig.OutputPulseParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='threshold', full_name='qm.grpc.qua_config.QuaConfig.OutputPulseParameters.threshold', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table', full_name='qm.grpc.qua_config.QuaConfig.OutputPulseParameters.table', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signalThreshold', full_name='qm.grpc.qua_config.QuaConfig.OutputPulseParameters.signalThreshold', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signalPolarity', full_name='qm.grpc.qua_config.QuaConfig.OutputPulseParameters.signalPolarity', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivativeThreshold', full_name='qm.grpc.qua_config.QuaConfig.OutputPulseParameters.derivativeThreshold', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivativePolarity', full_name='qm.grpc.qua_config.QuaConfig.OutputPulseParameters.derivativePolarity', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _QUACONFIG_OUTPUTPULSEPARAMETERS_POLARITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5583,
  serialized_end=5921,
)

_QUACONFIG_HOLDOFFSET = _descriptor.Descriptor(
  name='HoldOffset',
  full_name='qm.grpc.qua_config.QuaConfig.HoldOffset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='qm.grpc.qua_config.QuaConfig.HoldOffset.duration', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5923,
  serialized_end=5953,
)

_QUACONFIG_DACPORTREFERENCE = _descriptor.Descriptor(
  name='DacPortReference',
  full_name='qm.grpc.qua_config.QuaConfig.DacPortReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controller', full_name='qm.grpc.qua_config.QuaConfig.DacPortReference.controller', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='qm.grpc.qua_config.QuaConfig.DacPortReference.number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5955,
  serialized_end=6009,
)

_QUACONFIG_ADCPORTREFERENCE = _descriptor.Descriptor(
  name='AdcPortReference',
  full_name='qm.grpc.qua_config.QuaConfig.AdcPortReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controller', full_name='qm.grpc.qua_config.QuaConfig.AdcPortReference.controller', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='qm.grpc.qua_config.QuaConfig.AdcPortReference.number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6011,
  serialized_end=6065,
)

_QUACONFIG_DIGITALINPUTPORTREFERENCE = _descriptor.Descriptor(
  name='DigitalInputPortReference',
  full_name='qm.grpc.qua_config.QuaConfig.DigitalInputPortReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='qm.grpc.qua_config.QuaConfig.DigitalInputPortReference.port', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='qm.grpc.qua_config.QuaConfig.DigitalInputPortReference.delay', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='qm.grpc.qua_config.QuaConfig.DigitalInputPortReference.buffer', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6067,
  serialized_end=6184,
)

_QUACONFIG_DIGITALOUTPUTPORTREFERENCE = _descriptor.Descriptor(
  name='DigitalOutputPortReference',
  full_name='qm.grpc.qua_config.QuaConfig.DigitalOutputPortReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='qm.grpc.qua_config.QuaConfig.DigitalOutputPortReference.port', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6186,
  serialized_end=6273,
)

_QUACONFIG_PORTREFERENCE = _descriptor.Descriptor(
  name='PortReference',
  full_name='qm.grpc.qua_config.QuaConfig.PortReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controller', full_name='qm.grpc.qua_config.QuaConfig.PortReference.controller', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='qm.grpc.qua_config.QuaConfig.PortReference.number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6275,
  serialized_end=6326,
)

_QUACONFIG_PULSEDEC_WAVEFORMSENTRY = _descriptor.Descriptor(
  name='WaveformsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.PulseDec.WaveformsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.PulseDec.WaveformsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.PulseDec.WaveformsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6595,
  serialized_end=6643,
)

_QUACONFIG_PULSEDEC_INTEGRATIONWEIGHTSENTRY = _descriptor.Descriptor(
  name='IntegrationWeightsEntry',
  full_name='qm.grpc.qua_config.QuaConfig.PulseDec.IntegrationWeightsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.qua_config.QuaConfig.PulseDec.IntegrationWeightsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.PulseDec.IntegrationWeightsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6645,
  serialized_end=6702,
)

_QUACONFIG_PULSEDEC = _descriptor.Descriptor(
  name='PulseDec',
  full_name='qm.grpc.qua_config.QuaConfig.PulseDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='length', full_name='qm.grpc.qua_config.QuaConfig.PulseDec.length', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='qm.grpc.qua_config.QuaConfig.PulseDec.operation', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveforms', full_name='qm.grpc.qua_config.QuaConfig.PulseDec.waveforms', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalMarker', full_name='qm.grpc.qua_config.QuaConfig.PulseDec.digitalMarker', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integrationWeights', full_name='qm.grpc.qua_config.QuaConfig.PulseDec.integrationWeights', index=4,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUACONFIG_PULSEDEC_WAVEFORMSENTRY, _QUACONFIG_PULSEDEC_INTEGRATIONWEIGHTSENTRY, ],
  enum_types=[
    _QUACONFIG_PULSEDEC_OPERATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6329,
  serialized_end=6745,
)

_QUACONFIG_WAVEFORMDEC = _descriptor.Descriptor(
  name='WaveformDec',
  full_name='qm.grpc.qua_config.QuaConfig.WaveformDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='arbitrary', full_name='qm.grpc.qua_config.QuaConfig.WaveformDec.arbitrary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constant', full_name='qm.grpc.qua_config.QuaConfig.WaveformDec.constant', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compressed', full_name='qm.grpc.qua_config.QuaConfig.WaveformDec.compressed', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='waveform_oneof', full_name='qm.grpc.qua_config.QuaConfig.WaveformDec.waveform_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6748,
  serialized_end=7002,
)

_QUACONFIG_ARBITRARYWAVEFORMDEC = _descriptor.Descriptor(
  name='ArbitraryWaveformDec',
  full_name='qm.grpc.qua_config.QuaConfig.ArbitraryWaveformDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='samples', full_name='qm.grpc.qua_config.QuaConfig.ArbitraryWaveformDec.samples', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiplier', full_name='qm.grpc.qua_config.QuaConfig.ArbitraryWaveformDec.multiplier', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecatedMaxAllowedError', full_name='qm.grpc.qua_config.QuaConfig.ArbitraryWaveformDec.deprecatedMaxAllowedError', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxAllowedError', full_name='qm.grpc.qua_config.QuaConfig.ArbitraryWaveformDec.maxAllowedError', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='samplingRate', full_name='qm.grpc.qua_config.QuaConfig.ArbitraryWaveformDec.samplingRate', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isOverridable', full_name='qm.grpc.qua_config.QuaConfig.ArbitraryWaveformDec.isOverridable', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7005,
  serialized_end=7233,
)

_QUACONFIG_COMPRESSEDWAVEFORMDEC = _descriptor.Descriptor(
  name='CompressedWaveformDec',
  full_name='qm.grpc.qua_config.QuaConfig.CompressedWaveformDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='samples', full_name='qm.grpc.qua_config.QuaConfig.CompressedWaveformDec.samples', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampleRate', full_name='qm.grpc.qua_config.QuaConfig.CompressedWaveformDec.sampleRate', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7235,
  serialized_end=7295,
)

_QUACONFIG_CONSTANTWAVEFORMDEC = _descriptor.Descriptor(
  name='ConstantWaveformDec',
  full_name='qm.grpc.qua_config.QuaConfig.ConstantWaveformDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sample', full_name='qm.grpc.qua_config.QuaConfig.ConstantWaveformDec.sample', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiplier', full_name='qm.grpc.qua_config.QuaConfig.ConstantWaveformDec.multiplier', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7297,
  serialized_end=7354,
)

_QUACONFIG_DIGITALWAVEFORMDEC = _descriptor.Descriptor(
  name='DigitalWaveformDec',
  full_name='qm.grpc.qua_config.QuaConfig.DigitalWaveformDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='samples', full_name='qm.grpc.qua_config.QuaConfig.DigitalWaveformDec.samples', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7356,
  serialized_end=7446,
)

_QUACONFIG_DIGITALWAVEFORMSAMPLE = _descriptor.Descriptor(
  name='DigitalWaveformSample',
  full_name='qm.grpc.qua_config.QuaConfig.DigitalWaveformSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.DigitalWaveformSample.value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='qm.grpc.qua_config.QuaConfig.DigitalWaveformSample.length', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7448,
  serialized_end=7502,
)

_QUACONFIG_MIXERDEC = _descriptor.Descriptor(
  name='MixerDec',
  full_name='qm.grpc.qua_config.QuaConfig.MixerDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.qua_config.QuaConfig.MixerDec.correction', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7504,
  serialized_end=7581,
)

_QUACONFIG_INTEGRATIONWEIGHTDEC = _descriptor.Descriptor(
  name='IntegrationWeightDec',
  full_name='qm.grpc.qua_config.QuaConfig.IntegrationWeightDec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cosine', full_name='qm.grpc.qua_config.QuaConfig.IntegrationWeightDec.cosine', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sine', full_name='qm.grpc.qua_config.QuaConfig.IntegrationWeightDec.sine', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7584,
  serialized_end=7746,
)

_QUACONFIG_INTEGRATIONWEIGHTSAMPLE = _descriptor.Descriptor(
  name='IntegrationWeightSample',
  full_name='qm.grpc.qua_config.QuaConfig.IntegrationWeightSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua_config.QuaConfig.IntegrationWeightSample.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='qm.grpc.qua_config.QuaConfig.IntegrationWeightSample.length', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7748,
  serialized_end=7804,
)

_QUACONFIG_CORRECTIONENTRY = _descriptor.Descriptor(
  name='CorrectionEntry',
  full_name='qm.grpc.qua_config.QuaConfig.CorrectionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frequency', full_name='qm.grpc.qua_config.QuaConfig.CorrectionEntry.frequency', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loFrequency', full_name='qm.grpc.qua_config.QuaConfig.CorrectionEntry.loFrequency', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.qua_config.QuaConfig.CorrectionEntry.correction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frequencyNegative', full_name='qm.grpc.qua_config.QuaConfig.CorrectionEntry.frequencyNegative', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7807,
  serialized_end=7949,
)

_QUACONFIG_MATRIX = _descriptor.Descriptor(
  name='Matrix',
  full_name='qm.grpc.qua_config.QuaConfig.Matrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='v00', full_name='qm.grpc.qua_config.QuaConfig.Matrix.v00', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v01', full_name='qm.grpc.qua_config.QuaConfig.Matrix.v01', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v10', full_name='qm.grpc.qua_config.QuaConfig.Matrix.v10', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v11', full_name='qm.grpc.qua_config.QuaConfig.Matrix.v11', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7951,
  serialized_end=8011,
)

_QUACONFIG = _descriptor.Descriptor(
  name='QuaConfig',
  full_name='qm.grpc.qua_config.QuaConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='v1beta', full_name='qm.grpc.qua_config.QuaConfig.v1beta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='qm.grpc.qua_config.QuaConfig.revision', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUACONFIG_QUACONFIGV1, _QUACONFIG_CONTROLLERDEC, _QUACONFIG_ANALOGOUTPUTPORTDEC, _QUACONFIG_ANALOGOUTPUTPORTFILTER, _QUACONFIG_ANALOGINPUTPORTDEC, _QUACONFIG_DIGITALOUTPUTPORTDEC, _QUACONFIG_DIGITALINPUTPORTDEC, _QUACONFIG_MIXERREF, _QUACONFIG_OSCILLATOR, _QUACONFIG_SINGLEINPUT, _QUACONFIG_MIXINPUTS, _QUACONFIG_SINGLEINPUTCOLLECTION, _QUACONFIG_MULTIPLEINPUTS, _QUACONFIG_ELEMENTDEC, _QUACONFIG_ELEMENTTHREAD, _QUACONFIG_OUTPUTPULSEPARAMETERS, _QUACONFIG_HOLDOFFSET, _QUACONFIG_DACPORTREFERENCE, _QUACONFIG_ADCPORTREFERENCE, _QUACONFIG_DIGITALINPUTPORTREFERENCE, _QUACONFIG_DIGITALOUTPUTPORTREFERENCE, _QUACONFIG_PORTREFERENCE, _QUACONFIG_PULSEDEC, _QUACONFIG_WAVEFORMDEC, _QUACONFIG_ARBITRARYWAVEFORMDEC, _QUACONFIG_COMPRESSEDWAVEFORMDEC, _QUACONFIG_CONSTANTWAVEFORMDEC, _QUACONFIG_DIGITALWAVEFORMDEC, _QUACONFIG_DIGITALWAVEFORMSAMPLE, _QUACONFIG_MIXERDEC, _QUACONFIG_INTEGRATIONWEIGHTDEC, _QUACONFIG_INTEGRATIONWEIGHTSAMPLE, _QUACONFIG_CORRECTIONENTRY, _QUACONFIG_MATRIX, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_version', full_name='qm.grpc.qua_config.QuaConfig.config_version',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=112,
  serialized_end=8035,
)

_QUACONFIG_QUACONFIGV1_CONTROLLERSENTRY.fields_by_name['value'].message_type = _QUACONFIG_CONTROLLERDEC
_QUACONFIG_QUACONFIGV1_CONTROLLERSENTRY.containing_type = _QUACONFIG_QUACONFIGV1
_QUACONFIG_QUACONFIGV1_OSCILLATORSENTRY.fields_by_name['value'].message_type = _QUACONFIG_OSCILLATOR
_QUACONFIG_QUACONFIGV1_OSCILLATORSENTRY.containing_type = _QUACONFIG_QUACONFIGV1
_QUACONFIG_QUACONFIGV1_ELEMENTSENTRY.fields_by_name['value'].message_type = _QUACONFIG_ELEMENTDEC
_QUACONFIG_QUACONFIGV1_ELEMENTSENTRY.containing_type = _QUACONFIG_QUACONFIGV1
_QUACONFIG_QUACONFIGV1_PULSESENTRY.fields_by_name['value'].message_type = _QUACONFIG_PULSEDEC
_QUACONFIG_QUACONFIGV1_PULSESENTRY.containing_type = _QUACONFIG_QUACONFIGV1
_QUACONFIG_QUACONFIGV1_MIXERSENTRY.fields_by_name['value'].message_type = _QUACONFIG_MIXERDEC
_QUACONFIG_QUACONFIGV1_MIXERSENTRY.containing_type = _QUACONFIG_QUACONFIGV1
_QUACONFIG_QUACONFIGV1_WAVEFORMSENTRY.fields_by_name['value'].message_type = _QUACONFIG_WAVEFORMDEC
_QUACONFIG_QUACONFIGV1_WAVEFORMSENTRY.containing_type = _QUACONFIG_QUACONFIGV1
_QUACONFIG_QUACONFIGV1_DIGITALWAVEFORMSENTRY.fields_by_name['value'].message_type = _QUACONFIG_DIGITALWAVEFORMDEC
_QUACONFIG_QUACONFIGV1_DIGITALWAVEFORMSENTRY.containing_type = _QUACONFIG_QUACONFIGV1
_QUACONFIG_QUACONFIGV1_INTEGRATIONWEIGHTSENTRY.fields_by_name['value'].message_type = _QUACONFIG_INTEGRATIONWEIGHTDEC
_QUACONFIG_QUACONFIGV1_INTEGRATIONWEIGHTSENTRY.containing_type = _QUACONFIG_QUACONFIGV1
_QUACONFIG_QUACONFIGV1.fields_by_name['controllers'].message_type = _QUACONFIG_QUACONFIGV1_CONTROLLERSENTRY
_QUACONFIG_QUACONFIGV1.fields_by_name['oscillators'].message_type = _QUACONFIG_QUACONFIGV1_OSCILLATORSENTRY
_QUACONFIG_QUACONFIGV1.fields_by_name['elements'].message_type = _QUACONFIG_QUACONFIGV1_ELEMENTSENTRY
_QUACONFIG_QUACONFIGV1.fields_by_name['pulses'].message_type = _QUACONFIG_QUACONFIGV1_PULSESENTRY
_QUACONFIG_QUACONFIGV1.fields_by_name['mixers'].message_type = _QUACONFIG_QUACONFIGV1_MIXERSENTRY
_QUACONFIG_QUACONFIGV1.fields_by_name['waveforms'].message_type = _QUACONFIG_QUACONFIGV1_WAVEFORMSENTRY
_QUACONFIG_QUACONFIGV1.fields_by_name['digitalWaveforms'].message_type = _QUACONFIG_QUACONFIGV1_DIGITALWAVEFORMSENTRY
_QUACONFIG_QUACONFIGV1.fields_by_name['integrationWeights'].message_type = _QUACONFIG_QUACONFIGV1_INTEGRATIONWEIGHTSENTRY
_QUACONFIG_QUACONFIGV1.containing_type = _QUACONFIG
_QUACONFIG_CONTROLLERDEC_ANALOGOUTPUTSENTRY.fields_by_name['value'].message_type = _QUACONFIG_ANALOGOUTPUTPORTDEC
_QUACONFIG_CONTROLLERDEC_ANALOGOUTPUTSENTRY.containing_type = _QUACONFIG_CONTROLLERDEC
_QUACONFIG_CONTROLLERDEC_ANALOGINPUTSENTRY.fields_by_name['value'].message_type = _QUACONFIG_ANALOGINPUTPORTDEC
_QUACONFIG_CONTROLLERDEC_ANALOGINPUTSENTRY.containing_type = _QUACONFIG_CONTROLLERDEC
_QUACONFIG_CONTROLLERDEC_DIGITALOUTPUTSENTRY.fields_by_name['value'].message_type = _QUACONFIG_DIGITALOUTPUTPORTDEC
_QUACONFIG_CONTROLLERDEC_DIGITALOUTPUTSENTRY.containing_type = _QUACONFIG_CONTROLLERDEC
_QUACONFIG_CONTROLLERDEC_DIGITALINPUTSENTRY.fields_by_name['value'].message_type = _QUACONFIG_DIGITALINPUTPORTDEC
_QUACONFIG_CONTROLLERDEC_DIGITALINPUTSENTRY.containing_type = _QUACONFIG_CONTROLLERDEC
_QUACONFIG_CONTROLLERDEC.fields_by_name['analogOutputs'].message_type = _QUACONFIG_CONTROLLERDEC_ANALOGOUTPUTSENTRY
_QUACONFIG_CONTROLLERDEC.fields_by_name['analogInputs'].message_type = _QUACONFIG_CONTROLLERDEC_ANALOGINPUTSENTRY
_QUACONFIG_CONTROLLERDEC.fields_by_name['digitalOutputs'].message_type = _QUACONFIG_CONTROLLERDEC_DIGITALOUTPUTSENTRY
_QUACONFIG_CONTROLLERDEC.fields_by_name['digitalInputs'].message_type = _QUACONFIG_CONTROLLERDEC_DIGITALINPUTSENTRY
_QUACONFIG_CONTROLLERDEC.containing_type = _QUACONFIG
_QUACONFIG_ANALOGOUTPUTPORTDEC_CHANNELWEIGHTSENTRY.containing_type = _QUACONFIG_ANALOGOUTPUTPORTDEC
_QUACONFIG_ANALOGOUTPUTPORTDEC.fields_by_name['filter'].message_type = _QUACONFIG_ANALOGOUTPUTPORTFILTER
_QUACONFIG_ANALOGOUTPUTPORTDEC.fields_by_name['channelWeights'].message_type = _QUACONFIG_ANALOGOUTPUTPORTDEC_CHANNELWEIGHTSENTRY
_QUACONFIG_ANALOGOUTPUTPORTDEC.containing_type = _QUACONFIG
_QUACONFIG_ANALOGOUTPUTPORTFILTER.containing_type = _QUACONFIG
_QUACONFIG_ANALOGINPUTPORTDEC.fields_by_name['gainDb'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_QUACONFIG_ANALOGINPUTPORTDEC.containing_type = _QUACONFIG
_QUACONFIG_DIGITALOUTPUTPORTDEC.containing_type = _QUACONFIG
_QUACONFIG_DIGITALINPUTPORTDEC.fields_by_name['polarity'].enum_type = _QUACONFIG_DIGITALINPUTPORTDEC_POLARITY
_QUACONFIG_DIGITALINPUTPORTDEC.containing_type = _QUACONFIG
_QUACONFIG_DIGITALINPUTPORTDEC_POLARITY.containing_type = _QUACONFIG_DIGITALINPUTPORTDEC
_QUACONFIG_MIXERREF.containing_type = _QUACONFIG
_QUACONFIG_OSCILLATOR.fields_by_name['intermediateFrequency'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_QUACONFIG_OSCILLATOR.fields_by_name['mixer'].message_type = _QUACONFIG_MIXERREF
_QUACONFIG_OSCILLATOR.containing_type = _QUACONFIG
_QUACONFIG_SINGLEINPUT.fields_by_name['port'].message_type = _QUACONFIG_DACPORTREFERENCE
_QUACONFIG_SINGLEINPUT.containing_type = _QUACONFIG
_QUACONFIG_MIXINPUTS.fields_by_name['I'].message_type = _QUACONFIG_DACPORTREFERENCE
_QUACONFIG_MIXINPUTS.fields_by_name['Q'].message_type = _QUACONFIG_DACPORTREFERENCE
_QUACONFIG_MIXINPUTS.containing_type = _QUACONFIG
_QUACONFIG_SINGLEINPUTCOLLECTION_INPUTSENTRY.fields_by_name['value'].message_type = _QUACONFIG_DACPORTREFERENCE
_QUACONFIG_SINGLEINPUTCOLLECTION_INPUTSENTRY.containing_type = _QUACONFIG_SINGLEINPUTCOLLECTION
_QUACONFIG_SINGLEINPUTCOLLECTION.fields_by_name['inputs'].message_type = _QUACONFIG_SINGLEINPUTCOLLECTION_INPUTSENTRY
_QUACONFIG_SINGLEINPUTCOLLECTION.containing_type = _QUACONFIG
_QUACONFIG_MULTIPLEINPUTS_INPUTSENTRY.fields_by_name['value'].message_type = _QUACONFIG_DACPORTREFERENCE
_QUACONFIG_MULTIPLEINPUTS_INPUTSENTRY.containing_type = _QUACONFIG_MULTIPLEINPUTS
_QUACONFIG_MULTIPLEINPUTS.fields_by_name['inputs'].message_type = _QUACONFIG_MULTIPLEINPUTS_INPUTSENTRY
_QUACONFIG_MULTIPLEINPUTS.containing_type = _QUACONFIG
_QUACONFIG_ELEMENTDEC_OUTPUTSENTRY.fields_by_name['value'].message_type = _QUACONFIG_ADCPORTREFERENCE
_QUACONFIG_ELEMENTDEC_OUTPUTSENTRY.containing_type = _QUACONFIG_ELEMENTDEC
_QUACONFIG_ELEMENTDEC_DIGITALINPUTSENTRY.fields_by_name['value'].message_type = _QUACONFIG_DIGITALINPUTPORTREFERENCE
_QUACONFIG_ELEMENTDEC_DIGITALINPUTSENTRY.containing_type = _QUACONFIG_ELEMENTDEC
_QUACONFIG_ELEMENTDEC_DIGITALOUTPUTSENTRY.fields_by_name['value'].message_type = _QUACONFIG_DIGITALOUTPUTPORTREFERENCE
_QUACONFIG_ELEMENTDEC_DIGITALOUTPUTSENTRY.containing_type = _QUACONFIG_ELEMENTDEC
_QUACONFIG_ELEMENTDEC_OPERATIONSENTRY.containing_type = _QUACONFIG_ELEMENTDEC
_QUACONFIG_ELEMENTDEC.fields_by_name['outputs'].message_type = _QUACONFIG_ELEMENTDEC_OUTPUTSENTRY
_QUACONFIG_ELEMENTDEC.fields_by_name['digitalInputs'].message_type = _QUACONFIG_ELEMENTDEC_DIGITALINPUTSENTRY
_QUACONFIG_ELEMENTDEC.fields_by_name['digitalOutputs'].message_type = _QUACONFIG_ELEMENTDEC_DIGITALOUTPUTSENTRY
_QUACONFIG_ELEMENTDEC.fields_by_name['singleInput'].message_type = _QUACONFIG_SINGLEINPUT
_QUACONFIG_ELEMENTDEC.fields_by_name['mixInputs'].message_type = _QUACONFIG_MIXINPUTS
_QUACONFIG_ELEMENTDEC.fields_by_name['singleInputCollection'].message_type = _QUACONFIG_SINGLEINPUTCOLLECTION
_QUACONFIG_ELEMENTDEC.fields_by_name['multipleInputs'].message_type = _QUACONFIG_MULTIPLEINPUTS
_QUACONFIG_ELEMENTDEC.fields_by_name['timeOfFlight'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_QUACONFIG_ELEMENTDEC.fields_by_name['smearing'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_QUACONFIG_ELEMENTDEC.fields_by_name['intermediateFrequency'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_QUACONFIG_ELEMENTDEC.fields_by_name['operations'].message_type = _QUACONFIG_ELEMENTDEC_OPERATIONSENTRY
_QUACONFIG_ELEMENTDEC.fields_by_name['measurementQe'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_QUACONFIG_ELEMENTDEC.fields_by_name['outputPulseParameters'].message_type = _QUACONFIG_OUTPUTPULSEPARAMETERS
_QUACONFIG_ELEMENTDEC.fields_by_name['holdOffset'].message_type = _QUACONFIG_HOLDOFFSET
_QUACONFIG_ELEMENTDEC.fields_by_name['thread'].message_type = _QUACONFIG_ELEMENTTHREAD
_QUACONFIG_ELEMENTDEC.fields_by_name['intermediateFrequencyOscillator'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_QUACONFIG_ELEMENTDEC.fields_by_name['namedOscillator'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_QUACONFIG_ELEMENTDEC.fields_by_name['noOscillator'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_QUACONFIG_ELEMENTDEC.containing_type = _QUACONFIG
_QUACONFIG_ELEMENTDEC.oneofs_by_name['element_inputs_one_of'].fields.append(
  _QUACONFIG_ELEMENTDEC.fields_by_name['singleInput'])
_QUACONFIG_ELEMENTDEC.fields_by_name['singleInput'].containing_oneof = _QUACONFIG_ELEMENTDEC.oneofs_by_name['element_inputs_one_of']
_QUACONFIG_ELEMENTDEC.oneofs_by_name['element_inputs_one_of'].fields.append(
  _QUACONFIG_ELEMENTDEC.fields_by_name['mixInputs'])
_QUACONFIG_ELEMENTDEC.fields_by_name['mixInputs'].containing_oneof = _QUACONFIG_ELEMENTDEC.oneofs_by_name['element_inputs_one_of']
_QUACONFIG_ELEMENTDEC.oneofs_by_name['element_inputs_one_of'].fields.append(
  _QUACONFIG_ELEMENTDEC.fields_by_name['singleInputCollection'])
_QUACONFIG_ELEMENTDEC.fields_by_name['singleInputCollection'].containing_oneof = _QUACONFIG_ELEMENTDEC.oneofs_by_name['element_inputs_one_of']
_QUACONFIG_ELEMENTDEC.oneofs_by_name['element_inputs_one_of'].fields.append(
  _QUACONFIG_ELEMENTDEC.fields_by_name['multipleInputs'])
_QUACONFIG_ELEMENTDEC.fields_by_name['multipleInputs'].containing_oneof = _QUACONFIG_ELEMENTDEC.oneofs_by_name['element_inputs_one_of']
_QUACONFIG_ELEMENTDEC.oneofs_by_name['oscillator_one_of'].fields.append(
  _QUACONFIG_ELEMENTDEC.fields_by_name['intermediateFrequencyOscillator'])
_QUACONFIG_ELEMENTDEC.fields_by_name['intermediateFrequencyOscillator'].containing_oneof = _QUACONFIG_ELEMENTDEC.oneofs_by_name['oscillator_one_of']
_QUACONFIG_ELEMENTDEC.oneofs_by_name['oscillator_one_of'].fields.append(
  _QUACONFIG_ELEMENTDEC.fields_by_name['namedOscillator'])
_QUACONFIG_ELEMENTDEC.fields_by_name['namedOscillator'].containing_oneof = _QUACONFIG_ELEMENTDEC.oneofs_by_name['oscillator_one_of']
_QUACONFIG_ELEMENTDEC.oneofs_by_name['oscillator_one_of'].fields.append(
  _QUACONFIG_ELEMENTDEC.fields_by_name['noOscillator'])
_QUACONFIG_ELEMENTDEC.fields_by_name['noOscillator'].containing_oneof = _QUACONFIG_ELEMENTDEC.oneofs_by_name['oscillator_one_of']
_QUACONFIG_ELEMENTTHREAD.containing_type = _QUACONFIG
_QUACONFIG_OUTPUTPULSEPARAMETERS.fields_by_name['signalPolarity'].enum_type = _QUACONFIG_OUTPUTPULSEPARAMETERS_POLARITY
_QUACONFIG_OUTPUTPULSEPARAMETERS.fields_by_name['derivativePolarity'].enum_type = _QUACONFIG_OUTPUTPULSEPARAMETERS_POLARITY
_QUACONFIG_OUTPUTPULSEPARAMETERS.containing_type = _QUACONFIG
_QUACONFIG_OUTPUTPULSEPARAMETERS_POLARITY.containing_type = _QUACONFIG_OUTPUTPULSEPARAMETERS
_QUACONFIG_HOLDOFFSET.containing_type = _QUACONFIG
_QUACONFIG_DACPORTREFERENCE.containing_type = _QUACONFIG
_QUACONFIG_ADCPORTREFERENCE.containing_type = _QUACONFIG
_QUACONFIG_DIGITALINPUTPORTREFERENCE.fields_by_name['port'].message_type = _QUACONFIG_PORTREFERENCE
_QUACONFIG_DIGITALINPUTPORTREFERENCE.containing_type = _QUACONFIG
_QUACONFIG_DIGITALOUTPUTPORTREFERENCE.fields_by_name['port'].message_type = _QUACONFIG_PORTREFERENCE
_QUACONFIG_DIGITALOUTPUTPORTREFERENCE.containing_type = _QUACONFIG
_QUACONFIG_PORTREFERENCE.containing_type = _QUACONFIG
_QUACONFIG_PULSEDEC_WAVEFORMSENTRY.containing_type = _QUACONFIG_PULSEDEC
_QUACONFIG_PULSEDEC_INTEGRATIONWEIGHTSENTRY.containing_type = _QUACONFIG_PULSEDEC
_QUACONFIG_PULSEDEC.fields_by_name['waveforms'].message_type = _QUACONFIG_PULSEDEC_WAVEFORMSENTRY
_QUACONFIG_PULSEDEC.fields_by_name['digitalMarker'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_QUACONFIG_PULSEDEC.fields_by_name['integrationWeights'].message_type = _QUACONFIG_PULSEDEC_INTEGRATIONWEIGHTSENTRY
_QUACONFIG_PULSEDEC.containing_type = _QUACONFIG
_QUACONFIG_PULSEDEC_OPERATION.containing_type = _QUACONFIG_PULSEDEC
_QUACONFIG_WAVEFORMDEC.fields_by_name['arbitrary'].message_type = _QUACONFIG_ARBITRARYWAVEFORMDEC
_QUACONFIG_WAVEFORMDEC.fields_by_name['constant'].message_type = _QUACONFIG_CONSTANTWAVEFORMDEC
_QUACONFIG_WAVEFORMDEC.fields_by_name['compressed'].message_type = _QUACONFIG_COMPRESSEDWAVEFORMDEC
_QUACONFIG_WAVEFORMDEC.containing_type = _QUACONFIG
_QUACONFIG_WAVEFORMDEC.oneofs_by_name['waveform_oneof'].fields.append(
  _QUACONFIG_WAVEFORMDEC.fields_by_name['arbitrary'])
_QUACONFIG_WAVEFORMDEC.fields_by_name['arbitrary'].containing_oneof = _QUACONFIG_WAVEFORMDEC.oneofs_by_name['waveform_oneof']
_QUACONFIG_WAVEFORMDEC.oneofs_by_name['waveform_oneof'].fields.append(
  _QUACONFIG_WAVEFORMDEC.fields_by_name['constant'])
_QUACONFIG_WAVEFORMDEC.fields_by_name['constant'].containing_oneof = _QUACONFIG_WAVEFORMDEC.oneofs_by_name['waveform_oneof']
_QUACONFIG_WAVEFORMDEC.oneofs_by_name['waveform_oneof'].fields.append(
  _QUACONFIG_WAVEFORMDEC.fields_by_name['compressed'])
_QUACONFIG_WAVEFORMDEC.fields_by_name['compressed'].containing_oneof = _QUACONFIG_WAVEFORMDEC.oneofs_by_name['waveform_oneof']
_QUACONFIG_ARBITRARYWAVEFORMDEC.fields_by_name['maxAllowedError'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_QUACONFIG_ARBITRARYWAVEFORMDEC.fields_by_name['samplingRate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_QUACONFIG_ARBITRARYWAVEFORMDEC.containing_type = _QUACONFIG
_QUACONFIG_COMPRESSEDWAVEFORMDEC.containing_type = _QUACONFIG
_QUACONFIG_CONSTANTWAVEFORMDEC.containing_type = _QUACONFIG
_QUACONFIG_DIGITALWAVEFORMDEC.fields_by_name['samples'].message_type = _QUACONFIG_DIGITALWAVEFORMSAMPLE
_QUACONFIG_DIGITALWAVEFORMDEC.containing_type = _QUACONFIG
_QUACONFIG_DIGITALWAVEFORMSAMPLE.containing_type = _QUACONFIG
_QUACONFIG_MIXERDEC.fields_by_name['correction'].message_type = _QUACONFIG_CORRECTIONENTRY
_QUACONFIG_MIXERDEC.containing_type = _QUACONFIG
_QUACONFIG_INTEGRATIONWEIGHTDEC.fields_by_name['cosine'].message_type = _QUACONFIG_INTEGRATIONWEIGHTSAMPLE
_QUACONFIG_INTEGRATIONWEIGHTDEC.fields_by_name['sine'].message_type = _QUACONFIG_INTEGRATIONWEIGHTSAMPLE
_QUACONFIG_INTEGRATIONWEIGHTDEC.containing_type = _QUACONFIG
_QUACONFIG_INTEGRATIONWEIGHTSAMPLE.containing_type = _QUACONFIG
_QUACONFIG_CORRECTIONENTRY.fields_by_name['correction'].message_type = _QUACONFIG_MATRIX
_QUACONFIG_CORRECTIONENTRY.containing_type = _QUACONFIG
_QUACONFIG_MATRIX.containing_type = _QUACONFIG
_QUACONFIG.fields_by_name['v1beta'].message_type = _QUACONFIG_QUACONFIGV1
_QUACONFIG.oneofs_by_name['config_version'].fields.append(
  _QUACONFIG.fields_by_name['v1beta'])
_QUACONFIG.fields_by_name['v1beta'].containing_oneof = _QUACONFIG.oneofs_by_name['config_version']
DESCRIPTOR.message_types_by_name['QuaConfig'] = _QUACONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QuaConfig = _reflection.GeneratedProtocolMessageType('QuaConfig', (_message.Message,), {

  'QuaConfigV1' : _reflection.GeneratedProtocolMessageType('QuaConfigV1', (_message.Message,), {

    'ControllersEntry' : _reflection.GeneratedProtocolMessageType('ControllersEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_QUACONFIGV1_CONTROLLERSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.QuaConfigV1.ControllersEntry)
      })
    ,

    'OscillatorsEntry' : _reflection.GeneratedProtocolMessageType('OscillatorsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_QUACONFIGV1_OSCILLATORSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.QuaConfigV1.OscillatorsEntry)
      })
    ,

    'ElementsEntry' : _reflection.GeneratedProtocolMessageType('ElementsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_QUACONFIGV1_ELEMENTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.QuaConfigV1.ElementsEntry)
      })
    ,

    'PulsesEntry' : _reflection.GeneratedProtocolMessageType('PulsesEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_QUACONFIGV1_PULSESENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.QuaConfigV1.PulsesEntry)
      })
    ,

    'MixersEntry' : _reflection.GeneratedProtocolMessageType('MixersEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_QUACONFIGV1_MIXERSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.QuaConfigV1.MixersEntry)
      })
    ,

    'WaveformsEntry' : _reflection.GeneratedProtocolMessageType('WaveformsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_QUACONFIGV1_WAVEFORMSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.QuaConfigV1.WaveformsEntry)
      })
    ,

    'DigitalWaveformsEntry' : _reflection.GeneratedProtocolMessageType('DigitalWaveformsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_QUACONFIGV1_DIGITALWAVEFORMSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.QuaConfigV1.DigitalWaveformsEntry)
      })
    ,

    'IntegrationWeightsEntry' : _reflection.GeneratedProtocolMessageType('IntegrationWeightsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_QUACONFIGV1_INTEGRATIONWEIGHTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.QuaConfigV1.IntegrationWeightsEntry)
      })
    ,
    'DESCRIPTOR' : _QUACONFIG_QUACONFIGV1,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.QuaConfigV1)
    })
  ,

  'ControllerDec' : _reflection.GeneratedProtocolMessageType('ControllerDec', (_message.Message,), {

    'AnalogOutputsEntry' : _reflection.GeneratedProtocolMessageType('AnalogOutputsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_CONTROLLERDEC_ANALOGOUTPUTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogOutputsEntry)
      })
    ,

    'AnalogInputsEntry' : _reflection.GeneratedProtocolMessageType('AnalogInputsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_CONTROLLERDEC_ANALOGINPUTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogInputsEntry)
      })
    ,

    'DigitalOutputsEntry' : _reflection.GeneratedProtocolMessageType('DigitalOutputsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_CONTROLLERDEC_DIGITALOUTPUTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalOutputsEntry)
      })
    ,

    'DigitalInputsEntry' : _reflection.GeneratedProtocolMessageType('DigitalInputsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_CONTROLLERDEC_DIGITALINPUTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalInputsEntry)
      })
    ,
    'DESCRIPTOR' : _QUACONFIG_CONTROLLERDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ControllerDec)
    })
  ,

  'AnalogOutputPortDec' : _reflection.GeneratedProtocolMessageType('AnalogOutputPortDec', (_message.Message,), {

    'ChannelWeightsEntry' : _reflection.GeneratedProtocolMessageType('ChannelWeightsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_ANALOGOUTPUTPORTDEC_CHANNELWEIGHTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec.ChannelWeightsEntry)
      })
    ,
    'DESCRIPTOR' : _QUACONFIG_ANALOGOUTPUTPORTDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec)
    })
  ,

  'AnalogOutputPortFilter' : _reflection.GeneratedProtocolMessageType('AnalogOutputPortFilter', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_ANALOGOUTPUTPORTFILTER,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.AnalogOutputPortFilter)
    })
  ,

  'AnalogInputPortDec' : _reflection.GeneratedProtocolMessageType('AnalogInputPortDec', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_ANALOGINPUTPORTDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.AnalogInputPortDec)
    })
  ,

  'DigitalOutputPortDec' : _reflection.GeneratedProtocolMessageType('DigitalOutputPortDec', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_DIGITALOUTPUTPORTDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.DigitalOutputPortDec)
    })
  ,

  'DigitalInputPortDec' : _reflection.GeneratedProtocolMessageType('DigitalInputPortDec', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_DIGITALINPUTPORTDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.DigitalInputPortDec)
    })
  ,

  'MixerRef' : _reflection.GeneratedProtocolMessageType('MixerRef', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_MIXERREF,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.MixerRef)
    })
  ,

  'Oscillator' : _reflection.GeneratedProtocolMessageType('Oscillator', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_OSCILLATOR,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.Oscillator)
    })
  ,

  'SingleInput' : _reflection.GeneratedProtocolMessageType('SingleInput', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_SINGLEINPUT,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.SingleInput)
    })
  ,

  'MixInputs' : _reflection.GeneratedProtocolMessageType('MixInputs', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_MIXINPUTS,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.MixInputs)
    })
  ,

  'SingleInputCollection' : _reflection.GeneratedProtocolMessageType('SingleInputCollection', (_message.Message,), {

    'InputsEntry' : _reflection.GeneratedProtocolMessageType('InputsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_SINGLEINPUTCOLLECTION_INPUTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.SingleInputCollection.InputsEntry)
      })
    ,
    'DESCRIPTOR' : _QUACONFIG_SINGLEINPUTCOLLECTION,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.SingleInputCollection)
    })
  ,

  'MultipleInputs' : _reflection.GeneratedProtocolMessageType('MultipleInputs', (_message.Message,), {

    'InputsEntry' : _reflection.GeneratedProtocolMessageType('InputsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_MULTIPLEINPUTS_INPUTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.MultipleInputs.InputsEntry)
      })
    ,
    'DESCRIPTOR' : _QUACONFIG_MULTIPLEINPUTS,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.MultipleInputs)
    })
  ,

  'ElementDec' : _reflection.GeneratedProtocolMessageType('ElementDec', (_message.Message,), {

    'OutputsEntry' : _reflection.GeneratedProtocolMessageType('OutputsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_ELEMENTDEC_OUTPUTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ElementDec.OutputsEntry)
      })
    ,

    'DigitalInputsEntry' : _reflection.GeneratedProtocolMessageType('DigitalInputsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_ELEMENTDEC_DIGITALINPUTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ElementDec.DigitalInputsEntry)
      })
    ,

    'DigitalOutputsEntry' : _reflection.GeneratedProtocolMessageType('DigitalOutputsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_ELEMENTDEC_DIGITALOUTPUTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ElementDec.DigitalOutputsEntry)
      })
    ,

    'OperationsEntry' : _reflection.GeneratedProtocolMessageType('OperationsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_ELEMENTDEC_OPERATIONSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ElementDec.OperationsEntry)
      })
    ,
    'DESCRIPTOR' : _QUACONFIG_ELEMENTDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ElementDec)
    })
  ,

  'ElementThread' : _reflection.GeneratedProtocolMessageType('ElementThread', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_ELEMENTTHREAD,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ElementThread)
    })
  ,

  'OutputPulseParameters' : _reflection.GeneratedProtocolMessageType('OutputPulseParameters', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_OUTPUTPULSEPARAMETERS,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.OutputPulseParameters)
    })
  ,

  'HoldOffset' : _reflection.GeneratedProtocolMessageType('HoldOffset', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_HOLDOFFSET,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.HoldOffset)
    })
  ,

  'DacPortReference' : _reflection.GeneratedProtocolMessageType('DacPortReference', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_DACPORTREFERENCE,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.DacPortReference)
    })
  ,

  'AdcPortReference' : _reflection.GeneratedProtocolMessageType('AdcPortReference', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_ADCPORTREFERENCE,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.AdcPortReference)
    })
  ,

  'DigitalInputPortReference' : _reflection.GeneratedProtocolMessageType('DigitalInputPortReference', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_DIGITALINPUTPORTREFERENCE,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.DigitalInputPortReference)
    })
  ,

  'DigitalOutputPortReference' : _reflection.GeneratedProtocolMessageType('DigitalOutputPortReference', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_DIGITALOUTPUTPORTREFERENCE,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.DigitalOutputPortReference)
    })
  ,

  'PortReference' : _reflection.GeneratedProtocolMessageType('PortReference', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_PORTREFERENCE,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.PortReference)
    })
  ,

  'PulseDec' : _reflection.GeneratedProtocolMessageType('PulseDec', (_message.Message,), {

    'WaveformsEntry' : _reflection.GeneratedProtocolMessageType('WaveformsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_PULSEDEC_WAVEFORMSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.PulseDec.WaveformsEntry)
      })
    ,

    'IntegrationWeightsEntry' : _reflection.GeneratedProtocolMessageType('IntegrationWeightsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUACONFIG_PULSEDEC_INTEGRATIONWEIGHTSENTRY,
      '__module__' : 'qm.pb.inc_qua_config_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.PulseDec.IntegrationWeightsEntry)
      })
    ,
    'DESCRIPTOR' : _QUACONFIG_PULSEDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.PulseDec)
    })
  ,

  'WaveformDec' : _reflection.GeneratedProtocolMessageType('WaveformDec', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_WAVEFORMDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.WaveformDec)
    })
  ,

  'ArbitraryWaveformDec' : _reflection.GeneratedProtocolMessageType('ArbitraryWaveformDec', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_ARBITRARYWAVEFORMDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ArbitraryWaveformDec)
    })
  ,

  'CompressedWaveformDec' : _reflection.GeneratedProtocolMessageType('CompressedWaveformDec', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_COMPRESSEDWAVEFORMDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.CompressedWaveformDec)
    })
  ,

  'ConstantWaveformDec' : _reflection.GeneratedProtocolMessageType('ConstantWaveformDec', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_CONSTANTWAVEFORMDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.ConstantWaveformDec)
    })
  ,

  'DigitalWaveformDec' : _reflection.GeneratedProtocolMessageType('DigitalWaveformDec', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_DIGITALWAVEFORMDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.DigitalWaveformDec)
    })
  ,

  'DigitalWaveformSample' : _reflection.GeneratedProtocolMessageType('DigitalWaveformSample', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_DIGITALWAVEFORMSAMPLE,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.DigitalWaveformSample)
    })
  ,

  'MixerDec' : _reflection.GeneratedProtocolMessageType('MixerDec', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_MIXERDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.MixerDec)
    })
  ,

  'IntegrationWeightDec' : _reflection.GeneratedProtocolMessageType('IntegrationWeightDec', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_INTEGRATIONWEIGHTDEC,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.IntegrationWeightDec)
    })
  ,

  'IntegrationWeightSample' : _reflection.GeneratedProtocolMessageType('IntegrationWeightSample', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_INTEGRATIONWEIGHTSAMPLE,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.IntegrationWeightSample)
    })
  ,

  'CorrectionEntry' : _reflection.GeneratedProtocolMessageType('CorrectionEntry', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_CORRECTIONENTRY,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.CorrectionEntry)
    })
  ,

  'Matrix' : _reflection.GeneratedProtocolMessageType('Matrix', (_message.Message,), {
    'DESCRIPTOR' : _QUACONFIG_MATRIX,
    '__module__' : 'qm.pb.inc_qua_config_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig.Matrix)
    })
  ,
  'DESCRIPTOR' : _QUACONFIG,
  '__module__' : 'qm.pb.inc_qua_config_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.qua_config.QuaConfig)
  })
_sym_db.RegisterMessage(QuaConfig)
_sym_db.RegisterMessage(QuaConfig.QuaConfigV1)
_sym_db.RegisterMessage(QuaConfig.QuaConfigV1.ControllersEntry)
_sym_db.RegisterMessage(QuaConfig.QuaConfigV1.OscillatorsEntry)
_sym_db.RegisterMessage(QuaConfig.QuaConfigV1.ElementsEntry)
_sym_db.RegisterMessage(QuaConfig.QuaConfigV1.PulsesEntry)
_sym_db.RegisterMessage(QuaConfig.QuaConfigV1.MixersEntry)
_sym_db.RegisterMessage(QuaConfig.QuaConfigV1.WaveformsEntry)
_sym_db.RegisterMessage(QuaConfig.QuaConfigV1.DigitalWaveformsEntry)
_sym_db.RegisterMessage(QuaConfig.QuaConfigV1.IntegrationWeightsEntry)
_sym_db.RegisterMessage(QuaConfig.ControllerDec)
_sym_db.RegisterMessage(QuaConfig.ControllerDec.AnalogOutputsEntry)
_sym_db.RegisterMessage(QuaConfig.ControllerDec.AnalogInputsEntry)
_sym_db.RegisterMessage(QuaConfig.ControllerDec.DigitalOutputsEntry)
_sym_db.RegisterMessage(QuaConfig.ControllerDec.DigitalInputsEntry)
_sym_db.RegisterMessage(QuaConfig.AnalogOutputPortDec)
_sym_db.RegisterMessage(QuaConfig.AnalogOutputPortDec.ChannelWeightsEntry)
_sym_db.RegisterMessage(QuaConfig.AnalogOutputPortFilter)
_sym_db.RegisterMessage(QuaConfig.AnalogInputPortDec)
_sym_db.RegisterMessage(QuaConfig.DigitalOutputPortDec)
_sym_db.RegisterMessage(QuaConfig.DigitalInputPortDec)
_sym_db.RegisterMessage(QuaConfig.MixerRef)
_sym_db.RegisterMessage(QuaConfig.Oscillator)
_sym_db.RegisterMessage(QuaConfig.SingleInput)
_sym_db.RegisterMessage(QuaConfig.MixInputs)
_sym_db.RegisterMessage(QuaConfig.SingleInputCollection)
_sym_db.RegisterMessage(QuaConfig.SingleInputCollection.InputsEntry)
_sym_db.RegisterMessage(QuaConfig.MultipleInputs)
_sym_db.RegisterMessage(QuaConfig.MultipleInputs.InputsEntry)
_sym_db.RegisterMessage(QuaConfig.ElementDec)
_sym_db.RegisterMessage(QuaConfig.ElementDec.OutputsEntry)
_sym_db.RegisterMessage(QuaConfig.ElementDec.DigitalInputsEntry)
_sym_db.RegisterMessage(QuaConfig.ElementDec.DigitalOutputsEntry)
_sym_db.RegisterMessage(QuaConfig.ElementDec.OperationsEntry)
_sym_db.RegisterMessage(QuaConfig.ElementThread)
_sym_db.RegisterMessage(QuaConfig.OutputPulseParameters)
_sym_db.RegisterMessage(QuaConfig.HoldOffset)
_sym_db.RegisterMessage(QuaConfig.DacPortReference)
_sym_db.RegisterMessage(QuaConfig.AdcPortReference)
_sym_db.RegisterMessage(QuaConfig.DigitalInputPortReference)
_sym_db.RegisterMessage(QuaConfig.DigitalOutputPortReference)
_sym_db.RegisterMessage(QuaConfig.PortReference)
_sym_db.RegisterMessage(QuaConfig.PulseDec)
_sym_db.RegisterMessage(QuaConfig.PulseDec.WaveformsEntry)
_sym_db.RegisterMessage(QuaConfig.PulseDec.IntegrationWeightsEntry)
_sym_db.RegisterMessage(QuaConfig.WaveformDec)
_sym_db.RegisterMessage(QuaConfig.ArbitraryWaveformDec)
_sym_db.RegisterMessage(QuaConfig.CompressedWaveformDec)
_sym_db.RegisterMessage(QuaConfig.ConstantWaveformDec)
_sym_db.RegisterMessage(QuaConfig.DigitalWaveformDec)
_sym_db.RegisterMessage(QuaConfig.DigitalWaveformSample)
_sym_db.RegisterMessage(QuaConfig.MixerDec)
_sym_db.RegisterMessage(QuaConfig.IntegrationWeightDec)
_sym_db.RegisterMessage(QuaConfig.IntegrationWeightSample)
_sym_db.RegisterMessage(QuaConfig.CorrectionEntry)
_sym_db.RegisterMessage(QuaConfig.Matrix)


DESCRIPTOR._options = None
_QUACONFIG_QUACONFIGV1_CONTROLLERSENTRY._options = None
_QUACONFIG_QUACONFIGV1_OSCILLATORSENTRY._options = None
_QUACONFIG_QUACONFIGV1_ELEMENTSENTRY._options = None
_QUACONFIG_QUACONFIGV1_PULSESENTRY._options = None
_QUACONFIG_QUACONFIGV1_MIXERSENTRY._options = None
_QUACONFIG_QUACONFIGV1_WAVEFORMSENTRY._options = None
_QUACONFIG_QUACONFIGV1_DIGITALWAVEFORMSENTRY._options = None
_QUACONFIG_QUACONFIGV1_INTEGRATIONWEIGHTSENTRY._options = None
_QUACONFIG_CONTROLLERDEC_ANALOGOUTPUTSENTRY._options = None
_QUACONFIG_CONTROLLERDEC_ANALOGINPUTSENTRY._options = None
_QUACONFIG_CONTROLLERDEC_DIGITALOUTPUTSENTRY._options = None
_QUACONFIG_CONTROLLERDEC_DIGITALINPUTSENTRY._options = None
_QUACONFIG_ANALOGOUTPUTPORTDEC_CHANNELWEIGHTSENTRY._options = None
_QUACONFIG_SINGLEINPUTCOLLECTION_INPUTSENTRY._options = None
_QUACONFIG_MULTIPLEINPUTS_INPUTSENTRY._options = None
_QUACONFIG_ELEMENTDEC_OUTPUTSENTRY._options = None
_QUACONFIG_ELEMENTDEC_DIGITALINPUTSENTRY._options = None
_QUACONFIG_ELEMENTDEC_DIGITALOUTPUTSENTRY._options = None
_QUACONFIG_ELEMENTDEC_OPERATIONSENTRY._options = None
_QUACONFIG_OUTPUTPULSEPARAMETERS.fields_by_name['threshold']._options = None
_QUACONFIG_OUTPUTPULSEPARAMETERS.fields_by_name['table']._options = None
_QUACONFIG_PULSEDEC_WAVEFORMSENTRY._options = None
_QUACONFIG_PULSEDEC_INTEGRATIONWEIGHTSENTRY._options = None
_QUACONFIG_WAVEFORMDEC.fields_by_name['compressed']._options = None
_QUACONFIG_ARBITRARYWAVEFORMDEC.fields_by_name['deprecatedMaxAllowedError']._options = None
# @@protoc_insertion_point(module_scope)
